@@ -1,5 +1,5 @@
 <?php
-include_once getModulePath ( "polls" ) . "/classes/poll_factory.php";
+include_once getModulePath ( "polls", true ) . "/classes/poll_factory.php";
 $data = CustomData::get ();
 
 if (isset ( $data ["poll_id"] ) and is_numeric ( $data ["poll_id"] )) {
