@@ -1,5 +1,5 @@
 <?php
-include_once getModulePath ( "polls" ) . "/classes/poll_factory.php";
+include_once getModulePath ( "polls", true ) . "/classes/poll_factory.php";
 $acl = new ACL ();
 if ($acl->hasPermission ( "polls_edit" ) and isset ( $_REQUEST ["poll_stats"] )) {
 	echo Template::executeModuleTemplate ( "polls", "admin/stats" );
